@@ -3,16 +3,16 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenericAuthorization {
     /// Msg, identified by it's type URL, to grant unrestricted permissions to execute
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub msg: ::prost::alloc::string::String,
 }
 /// Grant gives permissions to execute
 /// the provide method with expiration time.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Grant {
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub authorization: ::core::option::Option<::prost_types::Any>,
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub expiration: ::core::option::Option<::prost_types::Timestamp>,
 }
 /// GrantAuthorization extends a grant with both the addresses of the grantee and granter.
@@ -21,208 +21,30 @@ pub struct Grant {
 /// Since: cosmos-sdk 0.45.2
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GrantAuthorization {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub authorization: ::core::option::Option<::prost_types::Any>,
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub expiration: ::core::option::Option<::prost_types::Timestamp>,
 }
-/// QueryGrantsRequest is the request type for the Query/Grants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGrantsRequest {
-    #[prost(string, tag = "1")]
-    pub granter: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
-    pub grantee: ::prost::alloc::string::String,
-    /// Optional, msg_type_url, when set, will query only grants matching given msg type.
-    #[prost(string, tag = "3")]
-    pub msg_type_url: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag = "4")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGrantsResponse is the response type for the Query/Authorizations RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGrantsResponse {
-    /// authorizations is a list of grants granted for grantee by granter.
-    #[prost(message, repeated, tag = "1")]
-    pub grants: ::prost::alloc::vec::Vec<Grant>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag = "2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-/// QueryGranterGrantsRequest is the request type for the Query/GranterGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranterGrantsRequest {
-    #[prost(string, tag = "1")]
-    pub granter: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag = "2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGranterGrantsResponse is the response type for the Query/GranterGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranterGrantsResponse {
-    /// grants is a list of grants granted by the granter.
-    #[prost(message, repeated, tag = "1")]
-    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag = "2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-/// QueryGranteeGrantsRequest is the request type for the Query/IssuedGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranteeGrantsRequest {
-    #[prost(string, tag = "1")]
-    pub grantee: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag = "2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGranteeGrantsResponse is the response type for the Query/GranteeGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranteeGrantsResponse {
-    /// grants is a list of grants granted to the grantee.
-    #[prost(message, repeated, tag = "1")]
-    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag = "2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-#[cfg(feature = "grpc")]
-#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
-pub mod query_client {
-    #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
-    use tonic::codegen::*;
-    #[doc = " Query defines the gRPC querier service."]
-    #[derive(Debug, Clone)]
-    pub struct QueryClient<T> {
-        inner: tonic::client::Grpc<T>,
-    }
-    impl QueryClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
-        pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
-        where
-            D: std::convert::TryInto<tonic::transport::Endpoint>,
-            D::Error: Into<StdError>,
-        {
-            let conn = tonic::transport::Endpoint::new(dst)?.connect().await?;
-            Ok(Self::new(conn))
-        }
-    }
-    impl<T> QueryClient<T>
-    where
-        T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
-        T::Error: Into<StdError>,
-        <T::ResponseBody as Body>::Error: Into<StdError> + Send,
-    {
-        pub fn new(inner: T) -> Self {
-            let inner = tonic::client::Grpc::new(inner);
-            Self { inner }
-        }
-        pub fn with_interceptor<F>(
-            inner: T,
-            interceptor: F,
-        ) -> QueryClient<InterceptedService<T, F>>
-        where
-            F: tonic::service::Interceptor,
-            T: tonic::codegen::Service<
-                http::Request<tonic::body::BoxBody>,
-                Response = http::Response<
-                    <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
-                >,
-            >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
-        {
-            QueryClient::new(InterceptedService::new(inner, interceptor))
-        }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
-        pub fn send_gzip(mut self) -> Self {
-            self.inner = self.inner.send_gzip();
-            self
-        }
-        #[doc = r" Enable decompressing responses with `gzip`."]
-        pub fn accept_gzip(mut self) -> Self {
-            self.inner = self.inner.accept_gzip();
-            self
-        }
-        #[doc = " Returns list of `Authorization`, granted to the grantee by the granter."]
-        pub async fn grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGrantsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Query/Grants");
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-        #[doc = " GranterGrants returns list of `GrantAuthorization`, granted by granter."]
-        #[doc = ""]
-        #[doc = " Since: cosmos-sdk 0.45.2"]
-        pub async fn granter_grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGranterGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGranterGrantsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Query/GranterGrants");
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-        #[doc = " GranteeGrants returns a list of `GrantAuthorization` by grantee."]
-        #[doc = ""]
-        #[doc = " Since: cosmos-sdk 0.45.2"]
-        pub async fn grantee_grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGranteeGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGranteeGrantsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Query/GranteeGrants");
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-    }
-}
 /// MsgGrant is a request type for Grant method. It declares authorization to the grantee
 /// on behalf of the granter with the provided expiration time.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgGrant {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub grant: ::core::option::Option<Grant>,
 }
 /// MsgExecResponse defines the Msg/MsgExecResponse response type.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgExecResponse {
-    #[prost(bytes = "vec", repeated, tag = "1")]
+    #[prost(bytes="vec", repeated, tag="1")]
     pub results: ::prost::alloc::vec::Vec<::prost::alloc::vec::Vec<u8>>,
 }
 /// MsgExec attempts to execute the provided messages using
@@ -230,44 +52,46 @@ pub struct MsgExecResponse {
 /// one signer corresponding to the granter of the authorization.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgExec {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub grantee: ::prost::alloc::string::String,
     /// Authorization Msg requests to execute. Each msg must implement Authorization interface
     /// The x/authz will try to find a grant matching (msg.signers\[0\], grantee, MsgTypeURL(msg))
     /// triple and validate it.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub msgs: ::prost::alloc::vec::Vec<::prost_types::Any>,
 }
 /// MsgGrantResponse defines the Msg/MsgGrant response type.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct MsgGrantResponse {}
+pub struct MsgGrantResponse {
+}
 /// MsgRevoke revokes any authorization with the provided sdk.Msg type on the
 /// granter's account with that has been granted to the grantee.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgRevoke {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub msg_type_url: ::prost::alloc::string::String,
 }
 /// MsgRevokeResponse defines the Msg/MsgRevokeResponse response type.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct MsgRevokeResponse {}
+pub struct MsgRevokeResponse {
+}
+/// Generated client implementations.
 #[cfg(feature = "grpc")]
 #[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
 pub mod msg_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Msg defines the authz Msg service."]
+    /// Msg defines the authz Msg service.
     #[derive(Debug, Clone)]
     pub struct MsgClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl MsgClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -280,123 +104,340 @@ pub mod msg_client {
     impl<T> MsgClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
             let inner = tonic::client::Grpc::new(inner);
             Self { inner }
         }
-        pub fn with_interceptor<F>(inner: T, interceptor: F) -> MsgClient<InterceptedService<T, F>>
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> MsgClient<InterceptedService<T, F>>
         where
             F: tonic::service::Interceptor,
+            T::ResponseBody: Default,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             MsgClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Grant grants the provided authorization to the grantee on the granter's"]
-        #[doc = " account with the provided expiration time. If there is already a grant"]
-        #[doc = " for the given (granter, grantee, Authorization) triple, then the grant"]
-        #[doc = " will be overwritten."]
+        /// Grant grants the provided authorization to the grantee on the granter's
+        /// account with the provided expiration time. If there is already a grant
+        /// for the given (granter, grantee, Authorization) triple, then the grant
+        /// will be overwritten.
         pub async fn grant(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgGrant>,
         ) -> Result<tonic::Response<super::MsgGrantResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Msg/Grant");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Msg/Grant",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Exec attempts to execute the provided messages using"]
-        #[doc = " authorizations granted to the grantee. Each message should have only"]
-        #[doc = " one signer corresponding to the granter of the authorization."]
+        /// Exec attempts to execute the provided messages using
+        /// authorizations granted to the grantee. Each message should have only
+        /// one signer corresponding to the granter of the authorization.
         pub async fn exec(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgExec>,
         ) -> Result<tonic::Response<super::MsgExecResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Msg/Exec");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Msg/Exec",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Revoke revokes any authorization corresponding to the provided method name on the"]
-        #[doc = " granter's account that has been granted to the grantee."]
+        /// Revoke revokes any authorization corresponding to the provided method name on the
+        /// granter's account that has been granted to the grantee.
         pub async fn revoke(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgRevoke>,
         ) -> Result<tonic::Response<super::MsgRevokeResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.authz.v1beta1.Msg/Revoke");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Msg/Revoke",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
 }
-/// GenesisState defines the authz module's genesis state.
+/// QueryGrantsRequest is the request type for the Query/Grants RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct GenesisState {
-    #[prost(message, repeated, tag = "1")]
-    pub authorization: ::prost::alloc::vec::Vec<GrantAuthorization>,
+pub struct QueryGrantsRequest {
+    #[prost(string, tag="1")]
+    pub granter: ::prost::alloc::string::String,
+    #[prost(string, tag="2")]
+    pub grantee: ::prost::alloc::string::String,
+    /// Optional, msg_type_url, when set, will query only grants matching given msg type.
+    #[prost(string, tag="3")]
+    pub msg_type_url: ::prost::alloc::string::String,
+    /// pagination defines an pagination for the request.
+    #[prost(message, optional, tag="4")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
+}
+/// QueryGrantsResponse is the response type for the Query/Authorizations RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGrantsResponse {
+    /// authorizations is a list of grants granted for grantee by granter.
+    #[prost(message, repeated, tag="1")]
+    pub grants: ::prost::alloc::vec::Vec<Grant>,
+    /// pagination defines an pagination for the response.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
+}
+/// QueryGranterGrantsRequest is the request type for the Query/GranterGrants RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGranterGrantsRequest {
+    #[prost(string, tag="1")]
+    pub granter: ::prost::alloc::string::String,
+    /// pagination defines an pagination for the request.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
+}
+/// QueryGranterGrantsResponse is the response type for the Query/GranterGrants RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGranterGrantsResponse {
+    /// grants is a list of grants granted by the granter.
+    #[prost(message, repeated, tag="1")]
+    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
+    /// pagination defines an pagination for the response.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
+}
+/// QueryGranteeGrantsRequest is the request type for the Query/IssuedGrants RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGranteeGrantsRequest {
+    #[prost(string, tag="1")]
+    pub grantee: ::prost::alloc::string::String,
+    /// pagination defines an pagination for the request.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
+}
+/// QueryGranteeGrantsResponse is the response type for the Query/GranteeGrants RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGranteeGrantsResponse {
+    /// grants is a list of grants granted to the grantee.
+    #[prost(message, repeated, tag="1")]
+    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
+    /// pagination defines an pagination for the response.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
+}
+/// Generated client implementations.
+#[cfg(feature = "grpc")]
+#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
+pub mod query_client {
+    #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
+    use tonic::codegen::*;
+    /// Query defines the gRPC querier service.
+    #[derive(Debug, Clone)]
+    pub struct QueryClient<T> {
+        inner: tonic::client::Grpc<T>,
+    }
+    impl QueryClient<tonic::transport::Channel> {
+        /// Attempt to create a new client by connecting to a given endpoint.
+        pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
+        where
+            D: std::convert::TryInto<tonic::transport::Endpoint>,
+            D::Error: Into<StdError>,
+        {
+            let conn = tonic::transport::Endpoint::new(dst)?.connect().await?;
+            Ok(Self::new(conn))
+        }
+    }
+    impl<T> QueryClient<T>
+    where
+        T: tonic::client::GrpcService<tonic::body::BoxBody>,
+        T::Error: Into<StdError>,
+        T::ResponseBody: Body<Data = Bytes> + Send + 'static,
+        <T::ResponseBody as Body>::Error: Into<StdError> + Send,
+    {
+        pub fn new(inner: T) -> Self {
+            let inner = tonic::client::Grpc::new(inner);
+            Self { inner }
+        }
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> QueryClient<InterceptedService<T, F>>
+        where
+            F: tonic::service::Interceptor,
+            T::ResponseBody: Default,
+            T: tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+                Response = http::Response<
+                    <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
+                >,
+            >,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
+        {
+            QueryClient::new(InterceptedService::new(inner, interceptor))
+        }
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
+        pub fn send_gzip(mut self) -> Self {
+            self.inner = self.inner.send_gzip();
+            self
+        }
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
+        pub fn accept_gzip(mut self) -> Self {
+            self.inner = self.inner.accept_gzip();
+            self
+        }
+        /// Returns list of `Authorization`, granted to the grantee by the granter.
+        pub async fn grants(
+            &mut self,
+            request: impl tonic::IntoRequest<super::QueryGrantsRequest>,
+        ) -> Result<tonic::Response<super::QueryGrantsResponse>, tonic::Status> {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
+            let codec = tonic::codec::ProstCodec::default();
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Query/Grants",
+            );
+            self.inner.unary(request.into_request(), path, codec).await
+        }
+        /// GranterGrants returns list of `GrantAuthorization`, granted by granter.
+        ///
+        /// Since: cosmos-sdk 0.45.2
+        pub async fn granter_grants(
+            &mut self,
+            request: impl tonic::IntoRequest<super::QueryGranterGrantsRequest>,
+        ) -> Result<tonic::Response<super::QueryGranterGrantsResponse>, tonic::Status> {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
+            let codec = tonic::codec::ProstCodec::default();
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Query/GranterGrants",
+            );
+            self.inner.unary(request.into_request(), path, codec).await
+        }
+        /// GranteeGrants returns a list of `GrantAuthorization` by grantee.
+        ///
+        /// Since: cosmos-sdk 0.45.2
+        pub async fn grantee_grants(
+            &mut self,
+            request: impl tonic::IntoRequest<super::QueryGranteeGrantsRequest>,
+        ) -> Result<tonic::Response<super::QueryGranteeGrantsResponse>, tonic::Status> {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
+            let codec = tonic::codec::ProstCodec::default();
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Query/GranteeGrants",
+            );
+            self.inner.unary(request.into_request(), path, codec).await
+        }
+    }
 }
 /// EventGrant is emitted on Msg/Grant
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct EventGrant {
     /// Msg type URL for which an autorization is granted
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub msg_type_url: ::prost::alloc::string::String,
     /// Granter account address
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub granter: ::prost::alloc::string::String,
     /// Grantee account address
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub grantee: ::prost::alloc::string::String,
 }
 /// EventRevoke is emitted on Msg/Revoke
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct EventRevoke {
     /// Msg type URL for which an autorization is revoked
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub msg_type_url: ::prost::alloc::string::String,
     /// Granter account address
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub granter: ::prost::alloc::string::String,
     /// Grantee account address
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub grantee: ::prost::alloc::string::String,
 }
+/// GenesisState defines the authz module's genesis state.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct GenesisState {
+    #[prost(message, repeated, tag="1")]
+    pub authorization: ::prost::alloc::vec::Vec<GrantAuthorization>,
+}
