@@ -2,80 +2,83 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Minter {
     /// current annual inflation rate
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub inflation: ::prost::alloc::string::String,
     /// current annual expected provisions
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub annual_provisions: ::prost::alloc::string::String,
 }
 /// Params holds parameters for the mint module.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Params {
     /// type of coin to mint
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub mint_denom: ::prost::alloc::string::String,
     /// maximum annual change in inflation rate
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub inflation_rate_change: ::prost::alloc::string::String,
     /// maximum inflation rate
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub inflation_max: ::prost::alloc::string::String,
     /// minimum inflation rate
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub inflation_min: ::prost::alloc::string::String,
     /// goal of percent bonded atoms
-    #[prost(string, tag = "5")]
+    #[prost(string, tag="5")]
     pub goal_bonded: ::prost::alloc::string::String,
     /// expected blocks per year
-    #[prost(uint64, tag = "6")]
+    #[prost(uint64, tag="6")]
     pub blocks_per_year: u64,
 }
 /// QueryParamsRequest is the request type for the Query/Params RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryParamsRequest {}
+pub struct QueryParamsRequest {
+}
 /// QueryParamsResponse is the response type for the Query/Params RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryParamsResponse {
     /// params defines the parameters of the module.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub params: ::core::option::Option<Params>,
 }
 /// QueryInflationRequest is the request type for the Query/Inflation RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryInflationRequest {}
+pub struct QueryInflationRequest {
+}
 /// QueryInflationResponse is the response type for the Query/Inflation RPC
 /// method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryInflationResponse {
     /// inflation is the current minting inflation value.
-    #[prost(bytes = "vec", tag = "1")]
+    #[prost(bytes="vec", tag="1")]
     pub inflation: ::prost::alloc::vec::Vec<u8>,
 }
 /// QueryAnnualProvisionsRequest is the request type for the
 /// Query/AnnualProvisions RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryAnnualProvisionsRequest {}
+pub struct QueryAnnualProvisionsRequest {
+}
 /// QueryAnnualProvisionsResponse is the response type for the
 /// Query/AnnualProvisions RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryAnnualProvisionsResponse {
     /// annual_provisions is the current minting annual provisions value.
-    #[prost(bytes = "vec", tag = "1")]
+    #[prost(bytes="vec", tag="1")]
     pub annual_provisions: ::prost::alloc::vec::Vec<u8>,
 }
+/// Generated client implementations.
 #[cfg(feature = "grpc")]
 #[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
 pub mod query_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Query provides defines the gRPC querier service."]
+    /// Query provides defines the gRPC querier service.
     #[derive(Debug, Clone)]
     pub struct QueryClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl QueryClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -88,8 +91,8 @@ pub mod query_client {
     impl<T> QueryClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -102,74 +105,95 @@ pub mod query_client {
         ) -> QueryClient<InterceptedService<T, F>>
         where
             F: tonic::service::Interceptor,
+            T::ResponseBody: Default,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             QueryClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Params returns the total set of minting parameters."]
+        /// Params returns the total set of minting parameters.
         pub async fn params(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryParamsRequest>,
         ) -> Result<tonic::Response<super::QueryParamsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.mint.v1beta1.Query/Params");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.mint.v1beta1.Query/Params",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Inflation returns the current minting inflation value."]
+        /// Inflation returns the current minting inflation value.
         pub async fn inflation(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryInflationRequest>,
         ) -> Result<tonic::Response<super::QueryInflationResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.mint.v1beta1.Query/Inflation");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.mint.v1beta1.Query/Inflation",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " AnnualProvisions current minting annual provisions value."]
+        /// AnnualProvisions current minting annual provisions value.
         pub async fn annual_provisions(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryAnnualProvisionsRequest>,
-        ) -> Result<tonic::Response<super::QueryAnnualProvisionsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+        ) -> Result<
+                tonic::Response<super::QueryAnnualProvisionsResponse>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.mint.v1beta1.Query/AnnualProvisions");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.mint.v1beta1.Query/AnnualProvisions",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
@@ -178,9 +202,9 @@ pub mod query_client {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenesisState {
     /// minter is a space for holding current inflation information.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub minter: ::core::option::Option<Minter>,
     /// params defines all the paramaters of the module.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub params: ::core::option::Option<Params>,
 }
