@@ -2,16 +2,16 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Tx {
     /// body is the processable content of the transaction
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub body: ::core::option::Option<TxBody>,
     /// auth_info is the authorization related content of the transaction,
     /// specifically signers, signer modes and fee
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub auth_info: ::core::option::Option<AuthInfo>,
     /// signatures is a list of signatures that matches the length and order of
     /// AuthInfo's signer_infos to allow connecting signature meta information like
     /// public key and signing mode by position.
-    #[prost(bytes = "vec", repeated, tag = "3")]
+    #[prost(bytes="vec", repeated, tag="3")]
     pub signatures: ::prost::alloc::vec::Vec<::prost::alloc::vec::Vec<u8>>,
 }
 /// TxRaw is a variant of Tx that pins the signer's exact binary representation
@@ -23,16 +23,16 @@ pub struct Tx {
 pub struct TxRaw {
     /// body_bytes is a protobuf serialization of a TxBody that matches the
     /// representation in SignDoc.
-    #[prost(bytes = "vec", tag = "1")]
+    #[prost(bytes="vec", tag="1")]
     pub body_bytes: ::prost::alloc::vec::Vec<u8>,
     /// auth_info_bytes is a protobuf serialization of an AuthInfo that matches the
     /// representation in SignDoc.
-    #[prost(bytes = "vec", tag = "2")]
+    #[prost(bytes="vec", tag="2")]
     pub auth_info_bytes: ::prost::alloc::vec::Vec<u8>,
     /// signatures is a list of signatures that matches the length and order of
     /// AuthInfo's signer_infos to allow connecting signature meta information like
     /// public key and signing mode by position.
-    #[prost(bytes = "vec", repeated, tag = "3")]
+    #[prost(bytes="vec", repeated, tag="3")]
     pub signatures: ::prost::alloc::vec::Vec<::prost::alloc::vec::Vec<u8>>,
 }
 /// SignDoc is the type used for generating sign bytes for SIGN_MODE_DIRECT.
@@ -40,19 +40,19 @@ pub struct TxRaw {
 pub struct SignDoc {
     /// body_bytes is protobuf serialization of a TxBody that matches the
     /// representation in TxRaw.
-    #[prost(bytes = "vec", tag = "1")]
+    #[prost(bytes="vec", tag="1")]
     pub body_bytes: ::prost::alloc::vec::Vec<u8>,
     /// auth_info_bytes is a protobuf serialization of an AuthInfo that matches the
     /// representation in TxRaw.
-    #[prost(bytes = "vec", tag = "2")]
+    #[prost(bytes="vec", tag="2")]
     pub auth_info_bytes: ::prost::alloc::vec::Vec<u8>,
     /// chain_id is the unique identifier of the chain this transaction targets.
     /// It prevents signed transactions from being used on another chain by an
     /// attacker
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub chain_id: ::prost::alloc::string::String,
     /// account_number is the account number of the account in state
-    #[prost(uint64, tag = "4")]
+    #[prost(uint64, tag="4")]
     pub account_number: u64,
 }
 /// TxBody is the body of a transaction that all signers sign over.
@@ -65,26 +65,26 @@ pub struct TxBody {
     /// By convention, the first required signer (usually from the first message)
     /// is referred to as the primary signer and pays the fee for the whole
     /// transaction.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub messages: ::prost::alloc::vec::Vec<::prost_types::Any>,
     /// memo is any arbitrary note/comment to be added to the transaction.
     /// WARNING: in clients, any publicly exposed text should not be called memo,
     /// but should be called `note` instead (see <https://github.com/cosmos/cosmos-sdk/issues/9122>).
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub memo: ::prost::alloc::string::String,
     /// timeout is the block height after which this transaction will not
     /// be processed by the chain
-    #[prost(uint64, tag = "3")]
+    #[prost(uint64, tag="3")]
     pub timeout_height: u64,
     /// extension_options are arbitrary options that can be added by chains
     /// when the default options are not sufficient. If any of these are present
     /// and can't be handled, the transaction will be rejected
-    #[prost(message, repeated, tag = "1023")]
+    #[prost(message, repeated, tag="1023")]
     pub extension_options: ::prost::alloc::vec::Vec<::prost_types::Any>,
     /// extension_options are arbitrary options that can be added by chains
     /// when the default options are not sufficient. If any of these are present
     /// and can't be handled, they will be ignored
-    #[prost(message, repeated, tag = "2047")]
+    #[prost(message, repeated, tag="2047")]
     pub non_critical_extension_options: ::prost::alloc::vec::Vec<::prost_types::Any>,
 }
 /// AuthInfo describes the fee and signer modes that are used to sign a
@@ -95,13 +95,13 @@ pub struct AuthInfo {
     /// and order of elements must match the required signers from TxBody's
     /// messages. The first element is the primary signer and the one which pays
     /// the fee.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub signer_infos: ::prost::alloc::vec::Vec<SignerInfo>,
     /// Fee is the fee and gas limit for the transaction. The first signer is the
     /// primary signer and the one which pays the fee. The fee can be calculated
     /// based on the cost of evaluating the body and doing signature verification
     /// of the signers. This can be estimated via simulation.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub fee: ::core::option::Option<Fee>,
 }
 /// SignerInfo describes the public key and signing mode of a single top-level
@@ -111,16 +111,16 @@ pub struct SignerInfo {
     /// public_key is the public key of the signer. It is optional for accounts
     /// that already exist in state. If unset, the verifier can use the required \
     /// signer address for this position and lookup the public key.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub public_key: ::core::option::Option<::prost_types::Any>,
     /// mode_info describes the signing mode of the signer and is a nested
     /// structure to support nested multisig pubkey's
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub mode_info: ::core::option::Option<ModeInfo>,
     /// sequence is the sequence of the account, which describes the
     /// number of committed transactions signed by a given address. It is used to
     /// prevent replay attacks.
-    #[prost(uint64, tag = "3")]
+    #[prost(uint64, tag="3")]
     pub sequence: u64,
 }
 /// ModeInfo describes the signing mode of a single or nested multisig signer.
@@ -128,7 +128,7 @@ pub struct SignerInfo {
 pub struct ModeInfo {
     /// sum is the oneof that specifies whether this represents a single or nested
     /// multisig signer
-    #[prost(oneof = "mode_info::Sum", tags = "1, 2")]
+    #[prost(oneof="mode_info::Sum", tags="1, 2")]
     pub sum: ::core::option::Option<mode_info::Sum>,
 }
 /// Nested message and enum types in `ModeInfo`.
@@ -139,19 +139,18 @@ pub mod mode_info {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Single {
         /// mode is the signing mode of the single signer
-        #[prost(enumeration = "super::super::signing::v1beta1::SignMode", tag = "1")]
+        #[prost(enumeration="super::super::signing::v1beta1::SignMode", tag="1")]
         pub mode: i32,
     }
     /// Multi is the mode info for a multisig public key
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Multi {
         /// bitarray specifies which keys within the multisig are signing
-        #[prost(message, optional, tag = "1")]
-        pub bitarray:
-            ::core::option::Option<super::super::super::crypto::multisig::v1beta1::CompactBitArray>,
+        #[prost(message, optional, tag="1")]
+        pub bitarray: ::core::option::Option<super::super::super::crypto::multisig::v1beta1::CompactBitArray>,
         /// mode_infos is the corresponding modes of the signers of the multisig
         /// which could include nested multisig public keys
-        #[prost(message, repeated, tag = "2")]
+        #[prost(message, repeated, tag="2")]
         pub mode_infos: ::prost::alloc::vec::Vec<super::ModeInfo>,
     }
     /// sum is the oneof that specifies whether this represents a single or nested
@@ -159,10 +158,10 @@ pub mod mode_info {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Sum {
         /// single represents a single signer
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Single(Single),
         /// multi represents a nested multisig signer
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         Multi(Multi),
     }
 }
@@ -172,21 +171,21 @@ pub mod mode_info {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Fee {
     /// amount is the amount of coins to be paid as a fee
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub amount: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     /// gas_limit is the maximum gas that can be used in transaction processing
     /// before an out of gas error occurs
-    #[prost(uint64, tag = "2")]
+    #[prost(uint64, tag="2")]
     pub gas_limit: u64,
     /// if unset, the first signer is responsible for paying the fees. If set, the specified account must pay the fees.
     /// the payer must be a tx signer (and thus have signed this field in AuthInfo).
     /// setting this field does *not* change the ordering of required signers for the transaction.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub payer: ::prost::alloc::string::String,
     /// if set, the fee payer (either the first signer or the value of the payer field) requests that a fee grant be used
     /// to pay fees instead of the fee payer's own balance. If an appropriate fee grant does not exist or the chain does
     /// not support fee grants, this will fail
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub granter: ::prost::alloc::string::String,
 }
 /// GetTxsEventRequest is the request type for the Service.TxsByEvents
@@ -194,12 +193,12 @@ pub struct Fee {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetTxsEventRequest {
     /// events is the list of transaction event type.
-    #[prost(string, repeated, tag = "1")]
+    #[prost(string, repeated, tag="1")]
     pub events: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// pagination defines a pagination for the request.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-    #[prost(enumeration = "OrderBy", tag = "3")]
+    #[prost(enumeration="OrderBy", tag="3")]
     pub order_by: i32,
 }
 /// GetTxsEventResponse is the response type for the Service.TxsByEvents
@@ -207,13 +206,13 @@ pub struct GetTxsEventRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetTxsEventResponse {
     /// txs is the list of queried transactions.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub txs: ::prost::alloc::vec::Vec<Tx>,
     /// tx_responses is the list of queried TxResponses.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub tx_responses: ::prost::alloc::vec::Vec<super::super::base::abci::v1beta1::TxResponse>,
     /// pagination defines a pagination for the response.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
 /// BroadcastTxRequest is the request type for the Service.BroadcastTxRequest
@@ -221,9 +220,9 @@ pub struct GetTxsEventResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BroadcastTxRequest {
     /// tx_bytes is the raw transaction.
-    #[prost(bytes = "vec", tag = "1")]
+    #[prost(bytes="vec", tag="1")]
     pub tx_bytes: ::prost::alloc::vec::Vec<u8>,
-    #[prost(enumeration = "BroadcastMode", tag = "2")]
+    #[prost(enumeration="BroadcastMode", tag="2")]
     pub mode: i32,
 }
 /// BroadcastTxResponse is the response type for the
@@ -231,7 +230,7 @@ pub struct BroadcastTxRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BroadcastTxResponse {
     /// tx_response is the queried TxResponses.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub tx_response: ::core::option::Option<super::super::base::abci::v1beta1::TxResponse>,
 }
 /// SimulateRequest is the request type for the Service.Simulate
@@ -241,12 +240,12 @@ pub struct SimulateRequest {
     /// tx is the transaction to simulate.
     /// Deprecated. Send raw tx bytes instead.
     #[deprecated]
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub tx: ::core::option::Option<Tx>,
     /// tx_bytes is the raw transaction.
     ///
     /// Since: cosmos-sdk 0.43
-    #[prost(bytes = "vec", tag = "2")]
+    #[prost(bytes="vec", tag="2")]
     pub tx_bytes: ::prost::alloc::vec::Vec<u8>,
 }
 /// SimulateResponse is the response type for the
@@ -254,10 +253,10 @@ pub struct SimulateRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SimulateResponse {
     /// gas_info is the information about gas used in the simulation.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub gas_info: ::core::option::Option<super::super::base::abci::v1beta1::GasInfo>,
     /// result is the result of the simulation.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub result: ::core::option::Option<super::super::base::abci::v1beta1::Result>,
 }
 /// GetTxRequest is the request type for the Service.GetTx
@@ -265,17 +264,17 @@ pub struct SimulateResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetTxRequest {
     /// hash is the tx hash to query, encoded as a hex string.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub hash: ::prost::alloc::string::String,
 }
 /// GetTxResponse is the response type for the Service.GetTx method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetTxResponse {
     /// tx is the queried transaction.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub tx: ::core::option::Option<Tx>,
     /// tx_response is the queried TxResponses.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub tx_response: ::core::option::Option<super::super::base::abci::v1beta1::TxResponse>,
 }
 /// GetBlockWithTxsRequest is the request type for the Service.GetBlockWithTxs
@@ -285,10 +284,10 @@ pub struct GetTxResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetBlockWithTxsRequest {
     /// height is the height of the block to query.
-    #[prost(int64, tag = "1")]
+    #[prost(int64, tag="1")]
     pub height: i64,
     /// pagination defines a pagination for the request.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
 }
 /// GetBlockWithTxsResponse is the response type for the Service.GetBlockWithTxs method.
@@ -297,14 +296,14 @@ pub struct GetBlockWithTxsRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetBlockWithTxsResponse {
     /// txs are the transactions in the block.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub txs: ::prost::alloc::vec::Vec<Tx>,
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub block_id: ::core::option::Option<::tendermint_proto::types::BlockId>,
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub block: ::core::option::Option<::tendermint_proto::types::Block>,
     /// pagination defines a pagination for the response.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
 /// OrderBy defines the sorting order
@@ -334,19 +333,19 @@ pub enum BroadcastMode {
     /// immediately.
     Async = 3,
 }
+/// Generated client implementations.
 #[cfg(feature = "grpc")]
 #[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
 pub mod service_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Service defines a gRPC service for interacting with transactions."]
+    /// Service defines a gRPC service for interacting with transactions.
     #[derive(Debug, Clone)]
     pub struct ServiceClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl ServiceClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -359,8 +358,8 @@ pub mod service_client {
     impl<T> ServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -373,108 +372,134 @@ pub mod service_client {
         ) -> ServiceClient<InterceptedService<T, F>>
         where
             F: tonic::service::Interceptor,
+            T::ResponseBody: Default,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             ServiceClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Simulate simulates executing a transaction for estimating gas usage."]
+        /// Simulate simulates executing a transaction for estimating gas usage.
         pub async fn simulate(
             &mut self,
             request: impl tonic::IntoRequest<super::SimulateRequest>,
         ) -> Result<tonic::Response<super::SimulateResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/Simulate");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.tx.v1beta1.Service/Simulate",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " GetTx fetches a tx by hash."]
+        /// GetTx fetches a tx by hash.
         pub async fn get_tx(
             &mut self,
             request: impl tonic::IntoRequest<super::GetTxRequest>,
         ) -> Result<tonic::Response<super::GetTxResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/GetTx");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.tx.v1beta1.Service/GetTx",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " BroadcastTx broadcast transaction."]
+        /// BroadcastTx broadcast transaction.
         pub async fn broadcast_tx(
             &mut self,
             request: impl tonic::IntoRequest<super::BroadcastTxRequest>,
         ) -> Result<tonic::Response<super::BroadcastTxResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/BroadcastTx");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.tx.v1beta1.Service/BroadcastTx",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " GetTxsEvent fetches txs by event."]
+        /// GetTxsEvent fetches txs by event.
         pub async fn get_txs_event(
             &mut self,
             request: impl tonic::IntoRequest<super::GetTxsEventRequest>,
         ) -> Result<tonic::Response<super::GetTxsEventResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/GetTxsEvent");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.tx.v1beta1.Service/GetTxsEvent",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " GetBlockWithTxs fetches a block with decoded txs."]
-        #[doc = ""]
-        #[doc = " Since: cosmos-sdk 0.45.2"]
+        /// GetBlockWithTxs fetches a block with decoded txs.
+        ///
+        /// Since: cosmos-sdk 0.45.2
         pub async fn get_block_with_txs(
             &mut self,
             request: impl tonic::IntoRequest<super::GetBlockWithTxsRequest>,
         ) -> Result<tonic::Response<super::GetBlockWithTxsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/GetBlockWithTxs");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.tx.v1beta1.Service/GetBlockWithTxs",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
